aboutsummaryrefslogtreecommitdiffstats
path: root/copy.sh
diff options
context:
space:
mode:
authorDon Williams <don.e.williams@gmail.com>2026-02-13 14:40:51 -0500
committerDon Williams <don.e.williams@gmail.com>2026-02-13 14:40:51 -0500
commit62f364ed911bff31aa1abc307322f7270aa0aff0 (patch)
tree7cb4d055d3bc4efbdb9ba261970d37307a6dae8a /copy.sh
parent9910e59796be08f84de5fe87bcaaebc807d5fce0 (diff)
Migrate Jakoolit to Linuxbeginnings repo references
Diffstat (limited to 'copy.sh')
-rwxr-xr-xcopy.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/copy.sh b/copy.sh
index 71d16572..ea582fca 100755
--- a/copy.sh
+++ b/copy.sh
@@ -1,7 +1,7 @@
#!/usr/bin/env bash
-# /* ---- 💫 https://github.com/JaKooLit 💫 ---- */ #
+# /* ---- 💫 https://github.com/LinuxBeginnings 💫 ---- */ #
# Purpose:
# Orchestrates copying/upgrading JaKooLit's Hyprland dotfiles into ~/.config.
# Handles interactive prompts, backups/restores, per-app tweaks, and express mode.
#
# Layout (high-level; future modularization targets):
@@ -630,7 +630,7 @@ else
case $WALL in
[Yy])
echo "${NOTE} Downloading additional wallpapers..."
- if git clone "https://github.com/JaKooLit/Wallpaper-Bank.git"; then
+ if git clone "https://github.com/LinuxBeginnings/Wallpaper-Bank.git"; then
echo "${OK} Wallpapers downloaded successfully." 2>&1 | tee -a "$LOG"
# Check if wallpapers directory exists and create it if not
send patches to the email below
@@ -1,7 +1,7 @@
# Purpose:
-# Orchestrates copying/upgrading JaKooLit's Hyprland dotfiles into ~/.config.
+# Orchestrates copying/upgrading LinuxBeginnings's Hyprland dotfiles into ~/.config.
# Handles interactive prompts, backups/restores, per-app tweaks, and express mode.
#
yukais@pinapelz.com
include the subject [PATCH repo_name]
pinapelz.com
homepage